==> apache-cloudstack-4.19.2.0-src.tar.bz2: apache-cloudstack-4.19.2.0-src/engine/storage/snapshot/src/main/java/org/apache/cloudstack/storage/snapshot/SnapshotStrategyBase.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.storage.snapshot;

import javax.inject.Inject;

import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotInfo;
import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotService;
import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotStrategy;

public abstract class SnapshotStrategyBase implements SnapshotStrategy {
    @Inject
    SnapshotService snapshotSvr;

    @Override
    public SnapshotInfo takeSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.takeSnapshot(snapshot).getSnapshot();
    }

    @Override
    public SnapshotInfo backupSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.backupSnapshot(snapshot);
    }

    @Override
    public boolean revertSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.revertSnapshot(snapshot);
    }
}

==> apache-cloudstack-4.20.2.0-src.tar.bz2: apache-cloudstack-4.20.2.0-src/engine/storage/snapshot/src/main/java/org/apache/cloudstack/storage/snapshot/SnapshotStrategyBase.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.storage.snapshot;

import javax.inject.Inject;

import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotInfo;
import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotService;
import org.apache.cloudstack.engine.subsystem.api.storage.SnapshotStrategy;
import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.LogManager;

public abstract class SnapshotStrategyBase implements SnapshotStrategy {
    protected Logger logger = LogManager.getLogger(getClass());
    @Inject
    SnapshotService snapshotSvr;

    @Override
    public SnapshotInfo takeSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.takeSnapshot(snapshot).getSnapshot();
    }

    @Override
    public SnapshotInfo backupSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.backupSnapshot(snapshot);
    }

    @Override
    public boolean revertSnapshot(SnapshotInfo snapshot) {
        return snapshotSvr.revertSnapshot(snapshot);
    }
}
